==> qt6-webengine_6.8.3+dfsg.orig.tar.xz: qtwebengine-everywhere-src-6.8.3/src/3rdparty/chromium/chrome/browser/resources/extensions/extensions.ts <==
// Copyright 2019 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

import './manager.js';

export {CrCheckboxElement} from 'chrome://resources/cr_elements/cr_checkbox/cr_checkbox.js';
export {getToastManager} from 'chrome://resources/cr_elements/cr_toast/cr_toast_manager.js';
export {PluralStringProxyImpl} from 'chrome://resources/js/plural_string_proxy.js';
export {IronIconElement} from 'chrome://resources/polymer/v3_0/iron-icon/iron-icon.js';
export {ActivityLogExtensionPlaceholder, ExtensionsActivityLogElement} from './activity_log/activity_log.js';
export {ActivityLogHistoryElement, ActivityLogPageState} from './activity_log/activity_log_history.js';
export {ActivityGroup, ActivityLogHistoryItemElement} from './activity_log/activity_log_history_item.js';
export {ActivityLogStreamElement} from './activity_log/activity_log_stream.js';
export {ActivityLogStreamItemElement, ARG_URL_PLACEHOLDER, StreamItem} from './activity_log/activity_log_stream_item.js';
export {ExtensionsCodeSectionElement} from './code_section.js';
export {ExtensionsDetailViewElement} from './detail_view.js';
export {ErrorPageDelegate, ExtensionsErrorPageElement} from './error_page.js';
export {ExtensionsHatsBrowserProxy, ExtensionsHatsBrowserProxyImpl} from './extension_hats_browser_proxy.js';
export {ExtensionsHostPermissionsToggleListElement} from './host_permissions_toggle_list.js';
export {ExtensionsItemElement, ItemDelegate} from './item.js';
export {ExtensionsItemListElement} from './item_list.js';
export {UserAction} from './item_util.js';
export {ExtensionsKeyboardShortcutsElement} from './keyboard_shortcuts.js';
// <if expr="chromeos_ash">
export {KioskApp, KioskAppSettings, KioskBrowserProxy, KioskBrowserProxyImpl, KioskSettings} from './kiosk_browser_proxy.js';
export {ExtensionsKioskDialogElement} from './kiosk_dialog.js';
// </if>
export {ExtensionsLoadErrorElement} from './load_error.js';
export {ExtensionsManagerElement} from './manager.js';
export {Dialog, navigation, NavigationHelper, Page, PageState} from './navigation_helper.js';
export {ExtensionsOptionsDialogElement, OptionsDialogMaxHeight, OptionsDialogMinWidth} from './options_dialog.js';
export {ExtensionsPackDialogElement, PackDialogDelegate} from './pack_dialog.js';
export {ExtensionsPackDialogAlertElement} from './pack_dialog_alert.js';
export {ExtensionsRestrictedSitesDialogElement} from './restricted_sites_dialog.js';
export {ExtensionsReviewPanelElement} from './review_panel.js';
export {ExtensionsRuntimeHostPermissionsElement} from './runtime_host_permissions.js';
export {ExtensionsRuntimeHostsDialogElement, getMatchingUserSpecifiedSites, getPatternFromSite} from './runtime_hosts_dialog.js';
export {Service, ServiceInterface} from './service.js';
export {ExtensionsShortcutInputElement} from './shortcut_input.js';
export {isValidKeyCode, Key, keystrokeToString} from './shortcut_util.js';
export {ExtensionsSidebarElement} from './sidebar.js';
export {ExtensionsSitePermissionsElement} from './site_permissions.js';
export {ExtensionsSitePermissionsBySiteElement} from './site_permissions_by_site.js';
export {SitePermissionsEditPermissionsDialogElement} from './site_permissions_edit_permissions_dialog.js';
export {getSitePermissionsPatternFromSite, SitePermissionsEditUrlDialogElement} from './site_permissions_edit_url_dialog.js';
export {ExtensionsSitePermissionsListElement} from './site_permissions_list.js';
export {SitePermissionsSiteGroupElement} from './site_permissions_site_group.js';
export {SiteSettingsMixin} from './site_settings_mixin.js';
export {ExtensionsToggleRowElement} from './toggle_row.js';
export {ExtensionsToolbarElement} from './toolbar.js';
export {getFaviconUrl} from './url_util.js';

==> qt6-webengine_6.9.2+dfsg.orig.tar.xz: qtwebengine-everywhere-src-6.9.2/src/3rdparty/chromium/chrome/browser/resources/extensions/extensions.ts <==
// Copyright 2019 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

import './manager.js';

export {CrCheckboxElement} from 'chrome://resources/cr_elements/cr_checkbox/cr_checkbox.js';
export {CrIconElement} from 'chrome://resources/cr_elements/cr_icon/cr_icon.js';
export {getToastManager} from 'chrome://resources/cr_elements/cr_toast/cr_toast_manager.js';
export {PluralStringProxyImpl} from 'chrome://resources/js/plural_string_proxy.js';
export {getTrustedHTML} from 'chrome://resources/js/static_types.js';
export {ActivityLogExtensionPlaceholder, ExtensionsActivityLogElement} from './activity_log/activity_log.js';
export {ActivityLogHistoryElement, ActivityLogPageState} from './activity_log/activity_log_history.js';
export {ActivityGroup, ActivityLogHistoryItemElement} from './activity_log/activity_log_history_item.js';
export {ActivityLogStreamElement} from './activity_log/activity_log_stream.js';
export {ActivityLogStreamItemElement, ARG_URL_PLACEHOLDER, StreamItem} from './activity_log/activity_log_stream_item.js';
export {ExtensionsCodeSectionElement} from './code_section.js';
export {ExtensionsDetailViewElement} from './detail_view.js';
export {ErrorPageDelegate, ExtensionsErrorPageElement} from './error_page.js';
export {ExtensionsHostPermissionsToggleListElement} from './host_permissions_toggle_list.js';
export {ExtensionsItemElement, ItemDelegate} from './item.js';
export {ExtensionsItemListElement} from './item_list.js';
export {UserAction} from './item_util.js';
export {ExtensionsKeyboardShortcutsElement} from './keyboard_shortcuts.js';
export {ExtensionsLoadErrorElement} from './load_error.js';
export {ExtensionsManagerElement} from './manager.js';
export {ExtensionsMv2DeprecationPanelElement} from './mv2_deprecation_panel.js';
export {Dialog, navigation, NavigationHelper, Page, PageState} from './navigation_helper.js';
export {ExtensionsOptionsDialogElement, OptionsDialogMaxHeight, OptionsDialogMinWidth} from './options_dialog.js';
export {ExtensionsPackDialogElement, PackDialogDelegate} from './pack_dialog.js';
export {ExtensionsPackDialogAlertElement} from './pack_dialog_alert.js';
export {ExtensionsRestrictedSitesDialogElement} from './restricted_sites_dialog.js';
export {ExtensionsReviewPanelElement} from './review_panel.js';
export {ExtensionsRuntimeHostPermissionsElement} from './runtime_host_permissions.js';
export {ExtensionsRuntimeHostsDialogElement, getMatchingUserSpecifiedSites, getPatternFromSite} from './runtime_hosts_dialog.js';
export {Service, ServiceInterface} from './service.js';
export {ExtensionsShortcutInputElement} from './shortcut_input.js';
export {isValidKeyCode, Key, keystrokeToString} from './shortcut_util.js';
export {ExtensionsSidebarElement} from './sidebar.js';
export {ExtensionsSitePermissionsElement} from './site_permissions/site_permissions.js';
export {ExtensionsSitePermissionsBySiteElement} from './site_permissions/site_permissions_by_site.js';
export {SitePermissionsEditPermissionsDialogElement} from './site_permissions/site_permissions_edit_permissions_dialog.js';
export {getSitePermissionsPatternFromSite, SitePermissionsEditUrlDialogElement} from './site_permissions/site_permissions_edit_url_dialog.js';
export {ExtensionsSitePermissionsListElement} from './site_permissions/site_permissions_list.js';
export {SitePermissionsSiteGroupElement} from './site_permissions/site_permissions_site_group.js';
export {SiteSettingsMixin} from './site_permissions/site_settings_mixin.js';
export {ExtensionsToggleRowElement} from './toggle_row.js';
export {ExtensionsToolbarElement} from './toolbar.js';
export {getFaviconUrl} from './url_util.js';
